package suicideChess;

/**
 * @author djib
 * 
 * This file contains the board representation.
 * The board is represented using bitboards.
 * a1 is square 0
 * h8 is square 7
 * a2 is square 8
 * ... and so on 
 * 
 * $LastChangedDate$
 * $LastChangedRevision$
 * $LastChangedBy$
 */

public class BitBoard {

	/*************
	 * CONSTANTS *
	 *************/
	
	//Some constants to make code more readable
	public static final int NB_OF_RANKS = 8;
	public static final int NB_OF_FILES = 8;
	public static final int NB_OF_SQUARES = NB_OF_RANKS*NB_OF_FILES; 
	
	//Some constants used to access the bitboards
	//Note that in suicide chess there may be more than one king
	public static final int WHITE_PAWNS = 0;
	public static final int BLACK_PAWNS = 1;
	public static final int WHITE_KINGS = 2;
	public static final int BLACK_KINGS = 3;
	public static final int WHITE_QUEENS = 4;
	public static final int BLACK_QUEENS = 5;
	public static final int WHITE_BISHOPS = 6;
	public static final int BLACK_BISHOPS = 7;
	public static final int WHITE_KNIGHTS = 8;
	public static final int BLACK_KNIGHTS = 9;
	public static final int WHITE_ROOKS = 10;
	public static final int BLACK_ROOKS = 11;
	public static final int WHITE_PIECES = 12;
	public static final int BLACK_PIECES = 13;
	
	public static final int NB_OF_BITBOARDS = 14;
	
		
	/********
	 * DATA *
	 ********/
	
	//The following table is used to map squares to bits
	private static long mapSquaresToBits[];
	
	//static function used to initialise data
	static {
		mapSquaresToBits = new long[NB_OF_SQUARES];
		for(int i=0; i<NB_OF_SQUARES; i++) {
			mapSquaresToBits[i] = (1L << i);
		}
	}
	
	//The following table contains all the bit boards
	private long bitBoards[];
	
	/***************
	 * CONSTRUCTOR *
	 ***************/
	
	public BitBoard() {
		bitBoards = new long[NB_OF_BITBOARDS];
	}
	
	
	/***********
	 * METHODS *
	 ***********/
	
	public long getBitboard(int bitboard_number) {
		return bitBoards[bitboard_number];
	}
		
	 
	public void updateBitboards(String move) {

	}

	
	public int squareToBitboardSquare(Square square) {
		//converts a square ("e2") to a BitboardSquare (
		return square.getFileNb() -1 + (square.getRank()-1)*NB_OF_FILES; 
	}
}